﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;

namespace PrintPreview
{
    public partial class CompassPrinterLayerProperty : Form
    {
        CompassPrinterLayer layer = null;

        public CompassPrinterLayerProperty(CompassPrinterLayer layer)
        {
            InitializeComponent();

            this.layer = layer;
        }


        private void Window_Load(object sender, EventArgs e)
        {
            LoadLayerProperties();
            LoadResize();
            LoadDrag();
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            SetLayerProperties();
            SetResize();
            SetDrag();
            Close();

            DialogResult = DialogResult.OK;
        }

        private void LoadLayerProperties()
        {
            if (layer.NeedleImage != null)
            {
                txtPath.Text = layer.NeedleImage.PathFilename;
            }
        }

        private void SetLayerProperties()
        {
            GeoImage image = new GeoImage(txtPath.Text);
            layer.NeedleImage = image;

            layer.Open();
            PointShape centerPoint = layer.GetPosition().GetCenterPoint();
            layer.SetPosition(image.GetWidth(), image.GetHeight(), centerPoint, PrintingUnit.Point);
        }

        private void LoadResize()
        {
            switch (layer.PrinterResizeMode)
            {
                case PrinterResizeMode.Fixed:
                    rbtnResizeFixed.Checked = true;
                    break;
                case PrinterResizeMode.MaintainAspectRatio:
                    rbtnResizeMaintainRaio.Checked = true;
                    break;
                case PrinterResizeMode.Resizable:
                    rbtnResize.Checked = true;
                    break;
                default:
                    break;
            }
        }

        private void SetResize()
        {
            if (rbtnResize.Checked)
            {
                layer.PrinterResizeMode = PrinterResizeMode.Resizable;
            }
            else if (rbtnResizeFixed.Checked)
            {
                layer.PrinterResizeMode = PrinterResizeMode.Fixed;
            }
            else if (rbtnResizeMaintainRaio.Checked)
            {
                layer.PrinterResizeMode = PrinterResizeMode.MaintainAspectRatio;
            }
        }

        private void LoadDrag()
        {
            switch (layer.PrinterDragMode)
            {
                case PrinterDragMode.Fixed:
                    rbtnDragFixed.Checked = true;
                    break;
                case PrinterDragMode.Dragable:
                    rbtnDraggable.Checked = true;
                    break;
                default:
                    break;
            }
        }

        private void SetDrag()
        {
            if (rbtnDragFixed.Checked)
            {
                layer.PrinterDragMode = PrinterDragMode.Fixed;
            }
            else if (rbtnDraggable.Checked)
            {
                layer.PrinterDragMode = PrinterDragMode.Dragable;
            }
        }


        private void btnBrowse_Click(object sender, EventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "All files (*.*)|*.*";
            ofd.RestoreDirectory = true;

            if (ofd.ShowDialog() == DialogResult.OK)
            {
                txtPath.Text = ofd.FileName;
            }
        }
    }
}
