﻿using System;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;

namespace PrintPreview
{
    public partial class ImagePrinterLayerProperty : Form
    {
        ImagePrinterLayer imagePrinterLayer = null;

        public ImagePrinterLayerProperty(ImagePrinterLayer imagePrinterLayer)
        {
            InitializeComponent();

            this.imagePrinterLayer = imagePrinterLayer;
        }

        private void Window_Load(object sender, EventArgs e)
        {
            LoadLayerProperties();
            LoadResize();
            LoadDrag();
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            SetLayerProperties();
            SetResize();
            SetDrag();
            Close();

            DialogResult = DialogResult.OK;
        }

        private void LoadLayerProperties()
        {
            txtPath.Text = imagePrinterLayer.Image.PathFilename;
        }

        private void SetLayerProperties()
        {
            GeoImage image = new GeoImage(txtPath.Text);
            imagePrinterLayer.Image = image;

            imagePrinterLayer.Open();
            PointShape centerPoint = imagePrinterLayer.GetPosition().GetCenterPoint();
            imagePrinterLayer.SetPosition(image.GetWidth(), image.GetHeight(), centerPoint, PrintingUnit.Point);
        }

        private void LoadResize()
        {
            switch (imagePrinterLayer.ResizeMode)
            {
                case PrinterResizeMode.Fixed:
                    rbtnResizeFixed.Checked = true;
                    break;
                case PrinterResizeMode.MaintainAspectRatio:
                    rbtnResizeMaintainRaio.Checked = true;
                    break;
                case PrinterResizeMode.Resizable:
                    rbtnResize.Checked = true;
                    break;
                default:
                    break;
            }
        }

        private void SetResize()
        {
            if (rbtnResize.Checked)
            {
                imagePrinterLayer.ResizeMode = PrinterResizeMode.Resizable;
            }
            else if (rbtnResizeFixed.Checked)
            {
                imagePrinterLayer.ResizeMode = PrinterResizeMode.Fixed;
            }
            else if (rbtnResizeMaintainRaio.Checked)
            {
                imagePrinterLayer.ResizeMode = PrinterResizeMode.MaintainAspectRatio;
            }
        }

        private void LoadDrag()
        {
            switch (imagePrinterLayer.DragMode)
            {
                case PrinterDragMode.Fixed:
                    rbtnDragFixed.Checked = true;
                    break;
                case PrinterDragMode.Draggable:
                    rbtnDraggable.Checked = true;
                    break;
                default:
                    break;
            }
        }

        private void SetDrag()
        {
            if (rbtnDragFixed.Checked)
            {
                imagePrinterLayer.DragMode = PrinterDragMode.Fixed;
            }
            else if (rbtnDraggable.Checked)
            {
                imagePrinterLayer.DragMode = PrinterDragMode.Draggable;
            }
        }

        private void btnBrowse_Click(object sender, EventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "All files (*.*)|*.*";
            ofd.RestoreDirectory = true;

            if (ofd.ShowDialog() == DialogResult.OK)
            {
                txtPath.Text = ofd.FileName;
            }
        }
 
    }
}
