﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;

namespace PrintPreview
{
    public partial class LabelPrinterLayerProperty : Form
    {
        LabelPrinterLayer labelPrinterLayer = null;

        public LabelPrinterLayerProperty(LabelPrinterLayer labelPrinterLayer)
        {
            InitializeComponent();

            this.labelPrinterLayer = labelPrinterLayer;
        }

        private void LabelPrinterLayerProperty_Load(object sender, EventArgs e)
        {
            LoadLayerProperties();
            LoadResize();
            LoadDrag();
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            SetLayerProperties();
            SetResize();
            SetDrag();
            Close();

            DialogResult = DialogResult.OK;
        }

        private void LoadLayerProperties()
        {
            txtText.Text = labelPrinterLayer.Text;
            lbFontSample.Font = GetFont(labelPrinterLayer.Font);
            lbFontSample.ForeColor = GetColor(((GeoSolidBrush)labelPrinterLayer.TextBrush).Color);

            if (labelPrinterLayer.PrinterWrapMode == PrinterWrapMode.WrapText)
            {
                chkEnableWrapText.Checked = true;
            }
            else
            {
                chkEnableWrapText.Checked = false;
            }
        }

        private void SetLayerProperties()
        {
            labelPrinterLayer.Text = txtText.Text;
            labelPrinterLayer.Font = GetGeoFont(lbFontSample.Font);
            ((GeoSolidBrush)labelPrinterLayer.TextBrush).Color = GetGeoColor(lbFontSample.ForeColor);

            if (chkEnableWrapText.Checked)
            {
                labelPrinterLayer.PrinterWrapMode = PrinterWrapMode.WrapText;
            }
            else
            {
                labelPrinterLayer.PrinterWrapMode = PrinterWrapMode.AutoSizeText;
            }
        }

        private Font GetFont(GeoFont geoFont)
        {
            return new Font(geoFont.FontName, geoFont.Size);
        }

        private GeoFont GetGeoFont(Font font)
        {
            return new GeoFont(font.FontFamily.Name, font.Size);
        }

        private Color GetColor(GeoColor geoColor)
        {
            return Color.FromArgb(geoColor.AlphaComponent, geoColor.RedComponent, geoColor.GreenComponent, geoColor.BlueComponent);
        }

        private GeoColor GetGeoColor(Color color)
        {
            return GeoColor.FromArgb(color.A, color.R, color.G, color.B);
        }

        private void btnChangeFont_Click(object sender, EventArgs e)
        {
            FontDialog fd = new FontDialog();
            fd.ShowColor = true;
            fd.Font = lbFontSample.Font;
            fd.Color = lbFontSample.ForeColor;

            if (fd.ShowDialog() != DialogResult.Cancel)
            {
                lbFontSample.Font = fd.Font;
                lbFontSample.ForeColor = fd.Color;
            }
        }

        private void LoadResize()
        {
            switch (labelPrinterLayer.ResizeMode)
            {
                case PrinterResizeMode.Fixed:
                    rbtnResizeFixed.Checked = true;
                    break;
                case PrinterResizeMode.MaintainAspectRatio:
                    rbtnResizeMaintainRaio.Checked = true;
                    break;
                case PrinterResizeMode.Resizable:
                    rbtnResize.Checked = true;
                    break;
                default:
                    break;
            }
        }

        private void SetResize()
        {
            if (rbtnResize.Checked)
            {
                labelPrinterLayer.ResizeMode = PrinterResizeMode.Resizable;
            }
            else if (rbtnResizeFixed.Checked)
            {
                labelPrinterLayer.ResizeMode = PrinterResizeMode.Fixed;
            }
            else if (rbtnResizeMaintainRaio.Checked)
            {
                labelPrinterLayer.ResizeMode = PrinterResizeMode.MaintainAspectRatio;
            }
        }

        private void LoadDrag()
        {
            switch (labelPrinterLayer.DragMode)
            {
                case PrinterDragMode.Fixed:
                    rbtnDragFixed.Checked = true;
                    break;
                case PrinterDragMode.Draggable:
                    rbtnDraggable.Checked = true;
                    break;
                default:
                    break;
            }
        }

        private void SetDrag()
        {
            if (rbtnDragFixed.Checked)
            {
                labelPrinterLayer.DragMode = PrinterDragMode.Fixed;
            }
            else if (rbtnDraggable.Checked)
            {
                labelPrinterLayer.DragMode = PrinterDragMode.Draggable;
            }
        }
    }
}
